Crate word_search_solver

Crate word_search_solver 

Functions

find_word_in_word_search
Finds the positions, if any, of the starting character of any matches in any direction. word_search is expected to be a 2d array with all rows being the same length. The resulting vec may have duplicates depending on if the starting character there has valid words in multiple directions.